;               Verify the CPU, disc, and drum model parameters.
;
;
; This include file checks that the parameters, if supplied, are legal CPU,
; disc, and drum models and sets the CPU, DISC, DRUM, SERIES, and DEVICE
; environment variables to the corresponding values.  It is invoked by the
; "tsb-*.sim" command files and is passed the first three invocation parameters
; as follows:
;
;    do parameters.inc [ <param-1> ] [ <param-2> ] [ <param-3> ]
;
; This file is never invoked directly by the user.
;
; The parameters may appear in any order and may be defaulted.  If an invalid
; parameter is supplied, this routine prints an error message and exits the
; simulator.
;
; On return, each environment variable will have one of these values:
;
;    CPU    = 2100, 21MX
;    DISC   = 7900, 2883
;    DRUM   = 2766, (null)
;    SERIES = 2100, 21MX
;    DEVICE = DPC, DQC
;
; CPU and DISC are set to the specific models requested or the default values if
; omitted, DRUM is set to 2766 if specified or null if not, SERIES is set to the
; general CPU type, and DEVICE is set to the disc simulator device code.


; Verify the CPU and disc model parameters.
;
; The legal parameter values are:
;
;   - CPU:  2100 (default) or 21MX
;   - Disc: 7900 (default) or 2883
;   - Drum: none (default) or 2766

set env ERROR=

if -I "%1" not in "","2100","21MX","7900","2883","2766" set env ERROR=Y
if -I "%2" not in "","2100","21MX","7900","2883","2766" set env ERROR=Y
if -I "%3" not in "","2100","21MX","7900","2883","2766" set env ERROR=Y

if "%ERROR%" != "" echo The CPU model parameter must be omitted or 2100 or 21MX,
if "%ERROR%" != "" echo the disc model parameter must be omitted or 7900 or 2883,
if "%ERROR%" != "" echo and the drum model parameter must be omitted or 2766.
if "%ERROR%" != "" exit


; Process the first parameter.

set env CPU=
set env DISC=
set env DRUM=

if    "%1" == "2100" set env CPU=2100  ; set env SERIES=2100
if -I "%1" == "21MX" set env CPU=21MX  ; set env SERIES=21MX

if    "%1" == "7900" set env DISC=7900 ; set env DEVICE=DPC
if    "%1" == "2883" set env DISC=2883 ; set env DEVICE=DQC

if    "%1" == "2766" set env DRUM=2766

; Process the second parameter.

if    "%2" == "2100" set env CPU=2100  ; set env SERIES=2100
if -I "%2" == "21MX" set env CPU=21MX  ; set env SERIES=21MX

if    "%2" == "7900" set env DISC=7900 ; set env DEVICE=DPC
if    "%2" == "2883" set env DISC=2883 ; set env DEVICE=DQC

if    "%2" == "2766" set env DRUM=2766


; Process the third parameter.

if    "%3" == "2100" set env CPU=2100  ; set env SERIES=2100
if -I "%3" == "21MX" set env CPU=21MX  ; set env SERIES=21MX

if    "%3" == "7900" set env DISC=7900 ; set env DEVICE=DPC
if    "%3" == "2883" set env DISC=2883 ; set env DEVICE=DQC

if    "%3" == "2766" set env DRUM=2766


; If the CPU and disc parameters were not specified, set up the defaults.

if "%CPU%"  == "" set env CPU=2100  ; set env SERIES=2100
if "%DISC%" == "" set env DISC=7900 ; set env DEVICE=DPC
