;                     Configure the 2000F System Processor.
;
;
; This include file configures the CPU and I/O card cage in the System Processor
; to contain the necessary device interfaces in the proper card slots.  It is
; invoked by the SP command files, as follows:
;
;    do spconfig.inc <cpu-model> <disc-model> [ <drum-model> ]
;
; ...where <cpu-model> and <disc-model> are the models of the CPU (2100 or
; 21MX) and disc (7900 or 2883) to use.  If <drum-model> is present, it will be
; "2766", as that is the only drum model supported.  This file is never invoked
; directly by the user.
;
; These device assignments are listed in the "Time-Shared BASIC/2000, Level F
; System Operator's Manual" (HP part number 02000-90074, November 1974):
;
;   Base  Optn
;    SC    SC   Device  Interface Description
;   ----  ----  ------  -----------------------------------------------------------
;    10    10    IPLI   12875A Processor Interconnect Lower Data PCA
;    11    11    IPLO   12875A Processor Interconnect Upper Data PCA
;    12    12    TTY    12531C Buffered Teleprinter Interface
;    13    13    PTR    12597A-002 Tape Reader Interface
;    --    14    DRD    12610B Drum Memory Interface Data Channel
;    --    15    DRC    12610B Drum Memory Interface Command Channel
;    14    16    TBG    12539C Time Base Generator Interface
;  / 15    17    DPD    13210A Disc Drive Interface Data Channel
;  \ 16    20    DPC    13210A Disc Drive Interface Command Channel
;  / 15    17    DQD    12565A Disc Interface Data Channel
;  \ 16    20    DQC    12565A Disc Interface Command Channel
;    17    --   (none)  12777A Priority Jumper Card
;    20    --   (none)  12777A Priority Jumper Card
;    21    21    MSD    13183B Digital Magnetic Tape Unit Interface Data Channel
;    22    22    MSC    13183B Digital Magnetic Tape Unit Interface Command Channel
;
; The "Base" select codes are used when the system does not host a drum, and
; the "Option" select codes are used when a drum is used.  The Priority Jumper
; cards permit invariant select codes for the magnetic tape interface.


; Configure the System Processor CPU.
;
; The SP requires floating-point support, which must be enabled specifically
; for 2100 CPUs (floating-point is standard on the 21MX series).

set CPU %1,32K

if "%1" == "2100" set CPU FP


; Configure and assign the select codes of the required devices.

set ALL DISABLED

set IPL ENABLED,SC=10
set TTY ENABLED,SC=12
set PTR ENABLED,SC=13
set TBG ENABLED,SC=14
set MSD ENABLED,SC=21


; Configure the tape drive interface model.

set MSC 13183


; Configure and assign the select code of the disc device.

if "%2" == "7900" set DPD ENABLED,SC=15 ; set DPC 13210
if "%2" == "2883" set DQD ENABLED,SC=15


; If the drum is specified, reconfigure the select codes to insert the drum
; interface cards.

if "%3" != "" set DRD ENABLED,SC=14 ; set DRC 512K ; set TBG SC=16
if "%3" != "" && "%2" == "7900" set DPD SC=17
if "%3" != "" && "%2" == "2883" set DQD SC=17


; Display the I/O configuration to the system operator.

show CPU IOCAGE
echo
